==> vega-viewer-0.3.2.jar: public/js/compiled/vega_viewer.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.object', 'goog.string.StringBuffer', 'goog.array']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../cljs/pprint.js", ['cljs.pprint'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer', 'clojure.string']);
goog.addDependency("../devcards/util/utils.js", ['devcards.util.utils'], ['cljs.core', 'goog.string.StringBuffer', 'cljs.pprint']);
goog.addDependency("../react.inc.js", ['cljsjs.react'], []);
goog.addDependency("../cljs/core/async/impl/protocols.js", ['cljs.core.async.impl.protocols'], ['cljs.core']);
goog.addDependency("../cljs/core/async/impl/buffers.js", ['cljs.core.async.impl.buffers'], ['cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/dispatch.js", ['cljs.core.async.impl.dispatch'], ['cljs.core', 'cljs.core.async.impl.buffers', 'goog.async.nextTick']);
goog.addDependency("../cljs/core/async/impl/channels.js", ['cljs.core.async.impl.channels'], ['cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.buffers', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/ioc_helpers.js", ['cljs.core.async.impl.ioc_helpers'], ['cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/timers.js", ['cljs.core.async.impl.timers'], ['cljs.core.async.impl.channels', 'cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async.js", ['cljs.core.async'], ['cljs.core.async.impl.channels', 'cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.buffers', 'cljs.core.async.impl.protocols', 'cljs.core.async.impl.ioc_helpers', 'cljs.core.async.impl.timers']);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../sablono/util.js", ['sablono.util'], ['goog.Uri', 'cljs.core', 'clojure.set', 'clojure.string']);
goog.addDependency("../sablono/interpreter.js", ['sablono.interpreter'], ['sablono.util', 'cljs.core', 'goog.object', 'cljsjs.react', 'clojure.string']);
goog.addDependency("../sablono/core.js", ['sablono.core'], ['goog.dom', 'sablono.util', 'goog.string', 'cljs.core', 'cljsjs.react', 'sablono.interpreter', 'clojure.string']);
goog.addDependency("../react-dom.inc.js", ['cljsjs.react.dom'], ['cljsjs.react']);
goog.addDependency("../devcards/util/edn_renderer.js", ['devcards.util.edn_renderer'], ['devcards.util.utils', 'cljs.core', 'sablono.core']);
goog.addDependency("../devcards/system.js", ['devcards.system'], ['devcards.util.utils', 'cljs.core', 'goog.history.EventType', 'cljsjs.react', 'goog.History', 'cljs.core.async', 'sablono.core', 'cljsjs.react.dom', 'devcards.util.edn_renderer', 'goog.labs.userAgent.device', 'clojure.string', 'goog.events']);
goog.addDependency("../cljs/test.js", ['cljs.test'], ['cljs.core', 'cljs.pprint', 'clojure.string']);
goog.addDependency("../showdown.inc.js", ['cljsjs.showdown'], []);
goog.addDependency("../devcards/util/markdown.js", ['devcards.util.markdown'], ['cljs.core', 'cljsjs.showdown', 'clojure.string']);
goog.addDependency("../devcards/core.js", ['devcards.core'], ['devcards.util.utils', 'devcards.system', 'cljs.core', 'cljs.test', 'cljs.core.async', 'sablono.core', 'devcards.util.edn_renderer', 'devcards.util.markdown', 'clojure.string']);
goog.addDependency("../om/dom.js", ['om.dom'], ['cljs.core', 'goog.object', 'cljsjs.react']);
goog.addDependency("../om/core.js", ['om.core'], ['goog.dom', 'cljs.core', 'om.dom', 'goog.dom.dataset', 'goog.object', 'cljsjs.react', 'goog.ui.IdGenerator']);
goog.addDependency("../d3.inc.js", ['cljsjs.d3'], []);
goog.addDependency("../vega.inc.js", ['cljsjs.vega'], ['cljsjs.d3']);
goog.addDependency("../vega_viewer/components/vega_viewer.js", ['vega_viewer.components.vega_viewer'], ['cljs.core', 'sablono.core', 'om.core', 'cljsjs.vega']);
goog.addDependency("../vega_viewer/vega/specs/constants.js", ['vega_viewer.vega.specs.constants'], ['cljs.core']);
goog.addDependency("../vega_viewer/vega/specs/utils.js", ['vega_viewer.vega.specs.utils'], ['vega_viewer.vega.specs.constants', 'cljs.core']);
goog.addDependency("../vega_viewer/vega/specs/horizontal_bar_chart.js", ['vega_viewer.vega.specs.horizontal_bar_chart'], ['vega_viewer.vega.specs.constants', 'cljs.core', 'vega_viewer.vega.specs.utils']);
goog.addDependency("../vega_viewer/components/horizontal_bar_chart.js", ['vega_viewer.components.horizontal_bar_chart'], ['vega_viewer.components.vega_viewer', 'cljs.core', 'vega_viewer.vega.specs.horizontal_bar_chart', 'sablono.core', 'om.core']);
goog.addDependency("../vega_viewer/vega/specs/histogram.js", ['vega_viewer.vega.specs.histogram'], ['vega_viewer.vega.specs.constants', 'cljs.core', 'vega_viewer.vega.specs.utils']);
goog.addDependency("../vega_viewer/components/histogram.js", ['vega_viewer.components.histogram'], ['vega_viewer.components.vega_viewer', 'cljs.core', 'sablono.core', 'vega_viewer.vega.specs.histogram', 'om.core']);
goog.addDependency("../vega_viewer/dev_cards.js", ['vega_viewer.dev_cards'], ['devcards.core', 'vega_viewer.components.vega_viewer', 'cljs.core', 'vega_viewer.components.horizontal_bar_chart', 'vega_viewer.components.histogram']);
goog.addDependency("../vega_viewer/vega/specs/stacked_horizontal_bar_chart.js", ['vega_viewer.vega.specs.stacked_horizontal_bar_chart'], ['vega_viewer.vega.specs.constants', 'cljs.core', 'vega_viewer.vega.specs.utils']);
goog.addDependency("../vega_viewer/components/stacked_horizontal_bar_chart.js", ['vega_viewer.components.stacked_horizontal_bar_chart'], ['vega_viewer.components.vega_viewer', 'cljs.core', 'sablono.core', 'om.core', 'vega_viewer.vega.specs.stacked_horizontal_bar_chart']);

==> vega-viewer-0.5.1-20160606.085745-1.jar: public/js/compiled/vega_viewer.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.object', 'goog.string.StringBuffer', 'goog.array']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../cljs/pprint.js", ['cljs.pprint'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer', 'clojure.string']);
goog.addDependency("../devcards/util/utils.js", ['devcards.util.utils'], ['cljs.core', 'goog.string.StringBuffer', 'cljs.pprint']);
goog.addDependency("../react.inc.js", ['cljsjs.react'], []);
goog.addDependency("../cljs/core/async/impl/protocols.js", ['cljs.core.async.impl.protocols'], ['cljs.core']);
goog.addDependency("../cljs/core/async/impl/buffers.js", ['cljs.core.async.impl.buffers'], ['cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/dispatch.js", ['cljs.core.async.impl.dispatch'], ['cljs.core', 'cljs.core.async.impl.buffers', 'goog.async.nextTick']);
goog.addDependency("../cljs/core/async/impl/channels.js", ['cljs.core.async.impl.channels'], ['cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.buffers', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/ioc_helpers.js", ['cljs.core.async.impl.ioc_helpers'], ['cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/timers.js", ['cljs.core.async.impl.timers'], ['cljs.core.async.impl.channels', 'cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async.js", ['cljs.core.async'], ['cljs.core.async.impl.channels', 'cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.buffers', 'cljs.core.async.impl.protocols', 'cljs.core.async.impl.ioc_helpers', 'cljs.core.async.impl.timers']);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../sablono/util.js", ['sablono.util'], ['goog.Uri', 'cljs.core', 'clojure.set', 'clojure.string']);
goog.addDependency("../sablono/interpreter.js", ['sablono.interpreter'], ['sablono.util', 'cljs.core', 'goog.object', 'cljsjs.react', 'clojure.string']);
goog.addDependency("../sablono/core.js", ['sablono.core'], ['goog.dom', 'sablono.util', 'goog.string', 'cljs.core', 'cljsjs.react', 'sablono.interpreter', 'clojure.string']);
goog.addDependency("../react-dom.inc.js", ['cljsjs.react.dom'], ['cljsjs.react']);
goog.addDependency("../devcards/util/edn_renderer.js", ['devcards.util.edn_renderer'], ['devcards.util.utils', 'cljs.core', 'sablono.core']);
goog.addDependency("../devcards/system.js", ['devcards.system'], ['devcards.util.utils', 'cljs.core', 'goog.history.EventType', 'cljsjs.react', 'goog.History', 'cljs.core.async', 'sablono.core', 'cljsjs.react.dom', 'devcards.util.edn_renderer', 'goog.labs.userAgent.device', 'clojure.string', 'goog.events']);
goog.addDependency("../cljs/test.js", ['cljs.test'], ['cljs.core', 'cljs.pprint', 'clojure.string']);
goog.addDependency("../showdown.inc.js", ['cljsjs.showdown'], []);
goog.addDependency("../devcards/util/markdown.js", ['devcards.util.markdown'], ['cljs.core', 'cljsjs.showdown', 'clojure.string']);
goog.addDependency("../devcards/core.js", ['devcards.core'], ['devcards.util.utils', 'devcards.system', 'cljs.core', 'cljs.test', 'cljs.core.async', 'sablono.core', 'devcards.util.edn_renderer', 'devcards.util.markdown', 'clojure.string']);
goog.addDependency("../vega_viewer/vega/specs/constants.js", ['vega_viewer.vega.specs.constants'], ['cljs.core']);
goog.addDependency("../vega_viewer/vega/specs/utils.js", ['vega_viewer.vega.specs.utils'], ['vega_viewer.vega.specs.constants', 'cljs.core', 'clojure.string']);
goog.addDependency("../om/dom.js", ['om.dom'], ['cljs.core', 'goog.object', 'cljsjs.react']);
goog.addDependency("../om/core.js", ['om.core'], ['goog.dom', 'cljs.core', 'om.dom', 'goog.dom.dataset', 'goog.object', 'cljsjs.react', 'goog.ui.IdGenerator']);
goog.addDependency("../d3.inc.js", ['cljsjs.d3'], []);
goog.addDependency("../vega.inc.js", ['cljsjs.vega'], ['cljsjs.d3']);
goog.addDependency("../vega_viewer/components/vega_viewer.js", ['vega_viewer.components.vega_viewer'], ['cljs.core', 'sablono.core', 'vega_viewer.vega.specs.utils', 'om.core', 'cljsjs.vega']);
goog.addDependency("../vega_viewer/vega/specs/horizontal_bar_chart.js", ['vega_viewer.vega.specs.horizontal_bar_chart'], ['vega_viewer.vega.specs.constants', 'cljs.core', 'vega_viewer.vega.specs.utils']);
goog.addDependency("../vega_viewer/components/horizontal_bar_chart.js", ['vega_viewer.components.horizontal_bar_chart'], ['vega_viewer.components.vega_viewer', 'cljs.core', 'vega_viewer.vega.specs.horizontal_bar_chart', 'sablono.core', 'om.core']);
goog.addDependency("../vega_viewer/vega/specs/histogram.js", ['vega_viewer.vega.specs.histogram'], ['vega_viewer.vega.specs.constants', 'cljs.core', 'vega_viewer.vega.specs.utils']);
goog.addDependency("../vega_viewer/components/histogram.js", ['vega_viewer.components.histogram'], ['vega_viewer.components.vega_viewer', 'cljs.core', 'sablono.core', 'vega_viewer.vega.specs.histogram', 'om.core']);
goog.addDependency("../vega_viewer/dev_cards.js", ['vega_viewer.dev_cards'], ['devcards.core', 'vega_viewer.components.vega_viewer', 'cljs.core', 'vega_viewer.components.horizontal_bar_chart', 'vega_viewer.components.histogram']);
goog.addDependency("../vega_viewer/vega/specs/stacked_horizontal_bar_chart.js", ['vega_viewer.vega.specs.stacked_horizontal_bar_chart'], ['vega_viewer.vega.specs.constants', 'cljs.core', 'vega_viewer.vega.specs.utils']);
goog.addDependency("../vega_viewer/components/stacked_horizontal_bar_chart.js", ['vega_viewer.components.stacked_horizontal_bar_chart'], ['vega_viewer.components.vega_viewer', 'cljs.core', 'sablono.core', 'om.core', 'vega_viewer.vega.specs.stacked_horizontal_bar_chart']);
